==> foundation-stories-0.19.0.tgz: package/stories/themes/stories/Palette.stories.tsx <==
/* eslint-disable @typescript-eslint/no-unsafe-assignment,
   @typescript-eslint/no-unsafe-member-access,
   @typescript-eslint/no-explicit-any
 */
import { readableColor } from 'polished';
import React from 'react';
import styled, { withTheme } from 'styled-components';

export default {
  title: 'Themes/Palette',
};

const PaletteWrap = styled.div`
  display: block;
  margin: 10px;
  width: 300px;

  > div :not(:last-child) {
    border-bottom: none;
  }
`;

// TODO: Fix ?? ''
const ColorRow = styled.div`
  background-color: ${(props) => props.color};
  border: 1px solid black;
  color: ${(props) => readableColor(props.color ?? '')};
  height: 50px;
  display: flex;
  align-items: center;
  padding: 10px;
  font-size: 12px;
`;

// TODO: Replace any, and remove ts-ignore
const Palette = ({ palette }: { palette: any }) => (
  <>
    {Object.entries(palette).map(([paletteName, paletteValue]) => (
      <PaletteWrap key={`pr-${paletteName}`}>
        {/* @ts-ignore */}
        <ColorRow color={palette[paletteName]}>
          {paletteName}: {paletteValue}
        </ColorRow>
      </PaletteWrap>
    ))}
  </>
);

const ThemedPalette = withTheme((props) => {
  const palette = { ...props.theme.palette };
  const { code, brand, dataVis, ...colors } = palette;

  return (
    <>
      <h1>Palette</h1>
      <Palette palette={colors} />
      <h1>Code palette</h1>
      <Palette palette={code} />
      <h1>Brand palette</h1>
      <Palette palette={brand} />
      <h1>DataVis palette</h1>
      <Palette palette={dataVis} />
    </>
  );
});

export const Default = () => <ThemedPalette />;

==> foundation-stories-0.41.1.tgz: package/stories/themes/stories/Palette.stories.tsx <==
/* eslint-disable @typescript-eslint/no-unsafe-assignment,
   @typescript-eslint/no-unsafe-member-access,
   @typescript-eslint/no-explicit-any
 */
import { readableColor } from 'polished';
import React from 'react';
import styled, { withTheme } from 'styled-components';

export default {
  title: 'Themes/Palette',
};

const PaletteWrap = styled.div`
  display: block;
  margin: 10px;
  width: 300px;

  > div :not(:last-child) {
    border-bottom: none;
  }
`;

// TODO: Fix ?? ''
const ColorRow = styled.div`
  background-color: ${(props) => props.color};
  border: 1px solid black;
  color: ${(props) => readableColor(props.color ?? '')};
  height: 50px;
  display: flex;
  align-items: center;
  padding: 10px;
  font-size: 12px;
`;

// TODO: Replace any, and remove ts-ignore
const Palette = ({ palette }: { palette: any }) => (
  <>
    {Object.entries(palette)
      .filter(([key, value]) => typeof value === 'string' && key !== 'mode')
      .map(([paletteName, paletteValue]) => (
        <PaletteWrap key={`pr-${paletteName}`}>
          {/* @ts-ignore */}
          <ColorRow color={palette[paletteName]}>
            {paletteName}: {paletteValue}
          </ColorRow>
        </PaletteWrap>
      ))}
  </>
);

const ThemedPalette = withTheme((props) => {
  const palette = { ...props.theme.palette };

  return (
    <>
      <h1>Palette</h1>
      <Palette palette={palette} />
      <h1>Code palette</h1>
      <Palette palette={palette.code} />
      <h1>Brand palette</h1>
      <Palette palette={palette.brand} />
      <h1>DataVis palette</h1>
      <Palette palette={palette.dataVis} />
    </>
  );
});

export const Default = () => <ThemedPalette />;
